%% DESCRIPTION
% Script for generating data used for testing behavior of machine learning
% algorithms to data with known underlying pattern and noise

%% Data generation
N = 1000;
categoricalLabels = ['A','B','C','D','E','F','G','H','I','J'];
c1 = categoricalLabels(randi(10,[N,1]))';
c2 = categoricalLabels(randi(4,[N,1]).*(randn(N,1) > 0.5)+1)';
c3 = categoricalLabels(randi(4,[N,1]).*(randn(N,1) > 0.5)+1)';
c4 = 3*rand(N,1);
c5 = 3*rand(N,1);

%% Random response
responseLabels = ['N','Y'];
response = responseLabels(randi(2,[N,1]))';
randomResponseData = table(c1, c2, c3, c4, c5, response,...
    'VariableNames',{'C1','C2','C3','C4','C5','Response'});
writetable(randomResponseData,'random_response_data.csv','Delimiter',',','QuoteStrings',true);

%% Known pattern response
response = char(N,1);
negativeCases = 0;
for sampleIdx=1:N
    if(c1(sampleIdx) == 'B' || c1(sampleIdx) == 'I')
        response(sampleIdx) = 'Y';
    elseif(c2(sampleIdx) == 'B')
        response(sampleIdx) = 'Y';
    elseif(c2(sampleIdx) >= 'C' && c4(sampleIdx) < 0.1)
        response(sampleIdx) = 'Y';
    elseif(c4(sampleIdx) < 0.3 && c1(sampleIdx) >= 'G')
        response(sampleIdx) = 'Y';
    elseif(c4(sampleIdx) > 2*c5(sampleIdx))
        response(sampleIdx) = 'Y';
    else
        response(sampleIdx) = 'N';
        negativeCases = negativeCases+1;
    end
end
knownResponseData = table(c1,c2,c3,c4,c5, response,...
    'VariableNames',{'C1','C2','C3','C4','C5','Response'});
writetable(knownResponseData,'known_response_data.csv','Delimiter',',','QuoteStrings',true);
